@@ -7,7 +7,7 @@ Code edited by CoolCoderSJ
 try:
 	from snow_pyrepl.api_pb2 import *
 except:
-	from snow_pyrepl import api_pb2
+	from import snow_pyrepl.api_pb2 import api_pb2
 import requests
 import websocket
 import random
@@ -22,7 +22,7 @@ def get_json(user, repl):
 	'''
 	return requests.get(f'https://replit.com/data/repls/@{user}/{repl}').json()
 
-def get_token(name, repl, key):
+def get_token(id, key):
 	'''
 	get_token(id: str, key: str)
 	Given a repl ID and an API key, get a one-time token for that repl.
@@ -37,9 +37,16 @@ def get_token(name, repl, key):
 	cookies = {
 		'connect.sid': key
 	}
-	r = requests.get(f'https://replit.com/@{name}/{repl}', headers=headers, cookies=cookies)
-	data = json.loads(r.text.split("<script id=\"__NEXT_DATA__\" type=\"application/json\">")[1].split("</script>")[0])['props']['pageProps']['connectionMetadata']
-	return data['token'], f"{data['gurl']}/wsv2/{data['token']}"
+	r = requests.post(f'https://replit.com/data/repls/{id}/get_connection_metadata', headers=headers, cookies=cookies)
+	return r.json()['token'], f"{r.json()['gurl']}/wsv2/{r.json()['token']}"
+
+def get_url(token, host, port, secure=False):
+	'''
+	get_url(token: str, host: str, port: str, [secure]: bool)
+	Gets the websocket connection URL for a given token, host, and port.
+	Normally the host will be eval.replit.com and the port will be 80.
+	'''
+	return f'ws{"s" if secure else ""}://{host}:{port}/wsv2/{token}'
 
 class PyReplError(Exception):
 	'''
@@ -101,7 +108,7 @@ class _Channel():
 		Returns a string of all output generate by sending a given message.
 		'''
 		got = self._send(data)
-		return [res for res in got]
+		return ''.join([res.output for res in got]) # Combine the outputs
 	def get_json(self, data):
 		'''
 		get_json(data: dict)
@@ -142,7 +149,6 @@ class Client():
 			res = api_pb2.OpenChannelRes() # Wait to get an OpenChannelRes
 			data = self.ws.recv()
 			res.ParseFromString(data)
-			print(res)
 			got = bool(res.id) # If we got one, then exit
 		self.channels.append(res.id)
 		return _Channel(res.id, service, name, self.ws) # Create the channel
